# Local
from stackexplain.stackexplain import main


if __name__ == "__main__":
    main()
